=======
Credits
=======

Development Lead
----------------

* Ben Lopatin <ben@wellfire.co>

Contributors
------------

* `Mathias Hansen <https://github.com/MiniCodeMonkey>`_
* `Antonio Gurgel <https://github.com/Goorzhel>`_
* `Marjorie Roswell <https://github.com/mroswell>`_
* `snake-plissken <https://github.com/snake-plissken>`_
* `Eric Theise <https://github.com/erictheise>`_
* `Nick Catalano <https://github.com/nickcatal>`_
* `Pedro Machado <https://github.com/pedromachados>`_
* `Josh Geller <https://github.com/joshgeller>`_
* `Shea Parkes <https://github.com/shea-parkes>`_
